===============================
pysrc3
===============================


.. image:: https://img.shields.io/pypi/v/pysrc3.svg
        :target: https://pypi.python.org/pypi/pysrc3

.. image:: https://img.shields.io/travis/astralblue/pysrc3.svg
        :target: https://travis-ci.org/astralblue/pysrc3

.. image:: https://readthedocs.org/projects/pysrc3/badge/?version=latest
        :target: https://pysrc3.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/astralblue/pysrc3/shield.svg
     :target: https://pyup.io/repos/github/astralblue/pysrc3/
     :alt: Updates


Opens the source file of Python modules in an editor, a pager, or any other program of choice.


* Free software: MIT license
* Documentation: https://pysrc3.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

